MRPModel-method-metadata: Return model metadata.

MRPModel-method-metadataR Documentation

Return model metadata.

Description

The ⁠$metadata()⁠ method of an MRPModel object returns the metadata associated with the model, including metadata inherited from a workflow object and model fitting parameters. Check out the More examples of R6 classes vignette for usage examples.

Usage

metadata()

Value

A list containing the model metadata.


shinymrp documentation built on Dec. 4, 2025, 5:07 p.m.