MRPModel-method-poststratify: Run poststratification to generate population estimates

MRPModel-method-poststratifyR Documentation

Run poststratification to generate population estimates

Description

The ⁠$poststratify()⁠ method of an MRPModel object runs Stan's standalone generated quantities and extracts posterior samples for poststratified estimates. This method is called by the ⁠$poststratify()⁠ method of a MRPWorkflow object and does not need to be called directly by users.

Usage

poststratify(interval = 0.95)

Arguments

interval

Confidence interval (a numeric value between 0 and 1) or standard deviation ("1sd" or "2sd") for the estimates (default is 0.95).

Value

A data.frame object containing the poststratified estimates and their corresponding uncertainty intervals.


shinymrp documentation built on Dec. 4, 2025, 5:07 p.m.