MRPModel-method-ppc: Create input for posterior predictive check

MRPModel-method-ppcR Documentation

Create input for posterior predictive check

Description

The ⁠$ppc()⁠ method of an MRPModel object runs Stan's standalone generated quantities to draw from the posterior predictive distribution. This method is called by the ⁠$pp_check()⁠ method of a MRPWorkflow object and does not need to be called directly by users.

Usage

ppc()

Value

A data.frame object containing samples from the posterior predictive distribution.


shinymrp documentation built on Dec. 4, 2025, 5:07 p.m.