MRPWorkflow-method-covar_hist: Create geographic covariate distribution histogram

MRPWorkflow-method-covar_histR Documentation

Create geographic covariate distribution histogram

Description

The covar_hist() method creates histogram plots showing the distribution of geographic covariates across ZIP codes. Refer to the More on data preparation for their definitions. This method is only available for COVID data. Check out the More examples of R6 classes vignette for usage examples.

Usage

covar_hist(covar, file = NULL, ...)

Arguments

covar

Character string specifying the geographic covariate. Options are "college", "poverty", "employment", "income", "urbanicity", and "adi".

file

Optional file path to save the plot.

...

Additional arguments passed to ggsave, such as width and height.

Value

A ggplot object showing the covariate distribution histogram.


shinymrp documentation built on Dec. 4, 2025, 5:07 p.m.