Learn R Programming

shinymrp (version 0.10.0)

MRPWorkflow-method-demo_bars: Create demographic comparison bar plots

Description

Creates bar plots for comparing demographic distributions between sample data and poststratification data. Check out the More examples of R6 classes vignette for usage examples.

Usage

demo_bars(demo, file = NULL, ...)

Value

A ggplot object showing demographic comparisons

Arguments

demo

Character string specifying the demographic variable to plot.

file

Optional file path to save the plot.

...

Additional arguments passed to ggsave, such as width and height.