| MRPWorkflow-method-estimate_map | R Documentation |
The $estimate_map() method creates interactive choropleth maps that show MRP estimates by geographic region.
This method cannot be used if either the sample or the poststratification data contains no geographic information.
Check out the More examples of R6 classes
vignette for usage examples.
estimate_map(
model,
geo = NULL,
time_index = NULL,
interval = 0.95,
file = NULL
)
model |
Fitted MRPModel object |
geo |
Character string specifying the geographic level for mapping.
Options include geography for data linking and those at larger scales.
A "linking" geography is required to use this method. It is either specified
as |
time_index |
Integer specifying the time index for time-varying data. |
interval |
Confidence interval (a numeric value between 0 and 1) or
standard deviation ( |
file |
Optional file path with .html extension to save the interactive map. Expand the hamburger menu in the top right corner of the map to access other export options. |
A highcharter map object showing MRP estimates by geography.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.