| MRPWorkflow-method-link_acs | R Documentation |
The $link_acs() method obtains poststratification data by
linking the preprocessed sample data to the American Community Survey
based on given geographic granularity and year. See the
More on data preparation
vignette for more information on data linking. For usage examples, refer to the
More examples of R6 classes
vignette.
link_acs(link_geo = NULL, acs_year = 2023)
link_geo |
Character string specifying the geographic level for linking. Options are |
acs_year |
Numeric value specifying the last year of the data collection period for the target ACS dataset. |
No return value, called for side effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.