| MRPWorkflow-method-load_pstrat | R Documentation |
The $load_pstrat() method processes and stores input poststratification data.
The object is subject to the same data preprocessing steps as the sample data. See the
More on data preparation
vignette for more information on data processing. For usage examples, refer to the
More examples of R6 classes
vignette.
load_pstrat(pstrat_data, is_aggregated = TRUE)
pstrat_data |
An object of class |
is_aggregated |
Logical indicating whether the poststratification data is already aggregated. |
No return value, called for side effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.