| MRPWorkflow-method-outcome_map | R Documentation |
The $outcome_map() method creates maps showing the average outcome values
by geography for cross-sectional data, or the highest/lowest temporal average for time-varying data.
The sample and poststratification data must contain geographic information for this method to work.
Check out the More examples of R6 classes
vignette for usage examples.
outcome_map(summary_type = NULL, file = NULL)
summary_type |
Character string, for time-varying data, indicating whether to display the
highest ( |
file |
Optional file path with .html extension to save the interactive map. Expand the hamburger menu in the top right corner of the map to access other export options. |
A highcharter map object showing average outcome measure by geography.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.