| MRPWorkflow-method-pp_check | R Documentation |
The $pp_check() method creates posterior predictive check plots
to assess model fit by comparing observed data to replicated data from
the posterior predictive distribution. Check out the
More examples of R6 classes
vignette for usage examples.
pp_check(model, file = NULL, ...)
model |
Fitted MRPModel object. |
file |
Optional file path to save the plot. |
... |
Additional arguments passed to |
A ggplot object showing the posterior predictive check result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.