| MRPWorkflow-method-sample_size_map | R Documentation |
The $sample_size_map() method creates interactive choropleth maps
showing data distribution with respect to geography. This method cannot be used
if either the sample or the poststratification data contains no geographic information.
Check out the More examples of R6 classes
vignette for usage examples.
sample_size_map(file = NULL)
file |
Optional file path with .html extension to save the interactive map. Expand the hamburger menu in the top right corner of the map to access other export options. |
A highcharter map object showing sample size distribution.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.