| example_sample_data | R Documentation |
Return example data based on the specified characteristics.
example_sample_data(
is_timevar = TRUE,
is_aggregated = TRUE,
special_case = NULL,
family = "binomial"
)
is_timevar |
Logical indicating whether the data is time-varying. |
is_aggregated |
Logical indicating whether the data is aggregated. |
special_case |
Optional character string for specific use cases such as COVID data.
Options are |
family |
Character string specifying the distribution family for outcome measures.
Options are |
A data.frame object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.