| run_app | R Documentation |
Run the Shiny Application
run_app(
onStart = NULL,
options = list(),
enableBookmarking = NULL,
uiPattern = "/",
launch.browser = TRUE,
...
)
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
launch.browser |
Logical; if TRUE (default) open in an external browser even when running inside RStudio. If FALSE, use RStudio Viewer (when available). |
... |
arguments passed into golem options via |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.