Learn R Programming

shinymrp (version 0.10.0)

MRPWorkflow-method-covar_hist: Create geographic covariate distribution histogram

Description

The covar_hist() method creates histogram plots showing the distribution of geographic covariates across ZIP codes. Refer to the More on data preparation for their definitions. This method is only available for COVID data. Check out the More examples of R6 classes vignette for usage examples.

Usage

covar_hist(covar, file = NULL, ...)

Value

A ggplot object showing the covariate distribution histogram.

Arguments

covar

Character string specifying the geographic covariate. Options are "college", "poverty", "employment", "income", "urbanicity", and "adi".

file

Optional file path to save the plot.

...

Additional arguments passed to ggsave, such as width and height.