Creates bar plots for comparing demographic distributions between sample data and poststratification data. Check out the More examples of R6 classes vignette for usage examples.
demo_bars(demo, file = NULL, ...)A ggplot object showing demographic comparisons
Character string specifying the demographic variable to plot.
Optional file path to save the plot.
Additional arguments passed to ggsave, such as width and height.