The $load_pstrat() method processes and stores input poststratification data.
The object is subject to the same data preprocessing steps as the sample data. See the
More on data preparation
vignette for more information on data processing. For usage examples, refer to the
More examples of R6 classes
vignette.
load_pstrat(pstrat_data, is_aggregated = TRUE)No return value, called for side effects.
An object of class data.frame (or one that can be coerced to that class).
Logical indicating whether the poststratification data is already aggregated.